.. _glossary:

Glossary
============================

.. glossary::

   Django 
        Django ist ein in :term:`Python` geschriebenes quelloffenes Web-Framework
        
        Siehe http://www.djangoproject.org für mehr.

   Python
        Python ist eine ausgereifte universale Programmiersprache, die für viele 
        verschiedenartige Lösungen angewendet werden kann. Python wird weltweit 
        von millionen Benutzern angewendet und von tausenden ständig weiterentwickelt.
        
        Siehe http://www.python.org für mehr.

   jQuery 
        jQuery ist ein freies, umfangreiches JavaScript-Framework, das komfortable 
        Funktionen zur DOM-Manipulation und -Navigation zur Verfügung stellt.

   Meta keywords        
        Nennt Stichwörter oder Themen, die auf der Webseite vorkommen bzw. 
        behandelt werden. Die Stichwörter werden durch Komma und nachfolgendem 
        Leerzeichen voneinander getrennt.
        
   Meta description
        Kurze Beschreibung des Inhalts der Webseite.
        
   Statischer Block
        Statisches HTML, das an mehreren Stellen des Shops eingefügt werden kann.
        I.d.R. im Kopf einer Kategorie-Seite.
        
   Top-Level-Kategorie
        Eine Kategorie, die keine übergeordnete Kategorie besitzt.
        